==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/CGI/Page.pm <==
#
# WiKicker
#
#  Page.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Page.pm,v 1.10 2004/04/30 08:28:53 naney Exp $
#
#

package WiKicker::CGI::Page;

use 5.005;
use strict;
use Carp;
use AutoLoader 'AUTOLOAD';

sub new {
  my ($class, %options) = @_;

  my $self = bless {
                    request => undef,
                   }, $class;

  if (exists $options{request}) {
    $self->{request} = $options{request};
  }

  return $self;
}

sub request {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{request} = $value;
  }
  return $self->{request};
}

# short cut
sub _get_properties {
  my ($self, $key) = @_;

  $self->request->configuration->properties->get($key);
}

sub action {
  my $self = shift;

  my $method = 'do_' . $self->request->action;
  my $result;
  eval {
    no strict "refs";
    $result = $self->$method();
  };
  if ($@) {
    my $message = $@;
    #warn $message;
    if ($message =~ /^Can't locate object method "(.*?)" via package "(.*?)"/) {
      my $no_method = $1;
      my $package = $2;
      if ($package eq ref $self && $no_method eq $method) {
        croak $self->_unknown_action_message;
      }
    }
    die $message;
  }
  return $result;
}

sub mail;

1;

__END__
sub mail {
  my ($self, $name, $mode, $content) = @_;

  WiKicker::Loader::load_module("WiKicker::CGI::Mailer");
  my $mailer = WiKicker::CGI::Mailer->new($self->request->configuration);
  $mailer->send_page_action_mail($name,
                                 $mode,
                                 $content,
                                 $self->request->user);
}

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/CGI/Page.pm <==
#
# WiKicker
#
#  Page.pm
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Page.pm,v 1.11 2004/06/20 06:28:11 naney Exp $
#
#

package WiKicker::CGI::Page;

use 5.005;
use strict;
use Carp;
use AutoLoader 'AUTOLOAD';

sub new {
  my ($class, %options) = @_;

  croak "no request parameter" unless exists $options{request};

  my $self = bless {
                    request => $options{request},
                   }, $class;

  return $self;
}

sub request {
  shift->{request};
}

# short cut
sub _get_properties {
  my ($self, $key) = @_;

  $self->request->configuration->properties->get($key);
}

sub action {
  my $self = shift;

  my $method = 'do_' . $self->request->action;
  my $result;
  eval {
    no strict 'refs';
    $result = $self->$method();
  };
  if ($@) {
    $self->_action_error($method, $@);
  }
  return $result;
}

sub mail;
sub _action_error;

1;

__END__
sub mail {
  my ($self, $name, $mode, $content) = @_;

  WiKicker::Loader::load_module('WiKicker::CGI::Mailer');
  my $mailer = WiKicker::CGI::Mailer->new($self->request->configuration);
  $mailer->send_page_action_mail($name,
                                 $mode,
                                 $content,
                                 $self->request->user);
}

sub _action_error {
  my ($self, $method, $message) = @_;

  if ($message =~ /^Can't locate object method "(.*?)" via package "(.*?)"/) {
    my $no_method = $1;
    my $package = $2;
    if ($package eq ref $self && $no_method eq $method) {
      # sub class must define _unknown_action_message method.
      croak $self->_unknown_action_message;
    }
  }
  croak "action: $method: $message";
}
